# <span class="badge package-core"></span> folder

## Objects

 * <span class="badge object-type-class"></span> [Folder](./object-Folder.md)
## Builders

 * <span class="badge builder"></span> [Folder](./builder-Folder.md)
